@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.005_01';
+our $VERSION = '0.005_02';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -13,7 +13,9 @@ use File::chdir;
 use File::Spec;
 use File::Basename qw/fileparse/;
 use Carp;
+no warnings;
 use Archive::Extract;
+use warnings;
 use Sort::Versions;
 use List::MoreUtils qw/uniq first_index/;
 use ExtUtils::Installed;
@@ -748,9 +750,6 @@ sub alien_find_lib_paths {
       grep { ! -d }
       @{ $self->_rscan_destdir( $dir, $file_pattern ) };
 
-    use YAML ();
-    print YAML::Dump({ files => \@files });
-
     for (@files) {
 
       my ($file, $path, $ext) = fileparse( $_, $file_pattern );
